cli

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package cli implements the command-line interface for dagrun.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App represents the CLI application.

func New

func New(stdout, stderr io.Writer) *App

New creates a new App with the given output writers.

func (*App) Run

func (a *App) Run(args []string) int

Run parses args and dispatches to the appropriate subcommand.

Jump to